@@ -17,7 +17,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '2.3'
+    return '2.3.1'
 
 
 def f_debug():
